Documentation
¶
Overview ¶
Package postgres provides a Postgres-specific wrapper around the hesper container library.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithDatabase ¶
func WithHostPort ¶
WithHostPort sets the host port that maps to the container's Postgres port (5432). This is required since the container runtime does not support ephemeral port assignment.
func WithInitScripts ¶
func WithPassword ¶
func WithUsername ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.